@@ -1,5 +1,8 @@
 #' @export
 .onLoad <- function(libname, pkgname) {
+  options(tidyllm_print_metadata = FALSE) # Default is to not print metadata
+  S7::methods_register()
+  
   # Initialize the parent environment for rate limits on package load
   if (!exists(".tidyllm_rate_limit_env", envir = .GlobalEnv)) {
     .GlobalEnv$.tidyllm_rate_limit_env <- new.env(parent = emptyenv())
@@ -11,14 +14,6 @@
 
 }
 
-#' @export
-.onAttach <- function(libname, pkgname) {
-  # Re-initialize or ensure the environment is set up when package is attached
-  if (!exists(".tidyllm_rate_limit_env", envir = .GlobalEnv)) {
-    .GlobalEnv$.tidyllm_rate_limit_env <- new.env(parent = emptyenv())
-  }
-  #Initialize the parent environment for streaming backups on package load
-  if (!exists(".tidyllm_stream_env", envir = .GlobalEnv)) {
-    .GlobalEnv$.tidyllm_stream_env <- new.env(parent = emptyenv())
-  }
-}
\ No newline at end of file
+# enable usage of <S7_object>@name in package code
+#' @rawNamespace if (getRversion() < "4.3.0") importFrom("S7", "@")
+NULL
\ No newline at end of file
